@@ -26,12 +26,12 @@ static struct FS supported_fs[] = {
     { "hfsplus", "nosuid,nodev,user", 1, NULL, 0 },
     { "hfs", "nosuid,nodev,user", 1, "077", NULL, 
       ",file_umask=%04o,dir_umask=%04o"},
-    { "ext3", "nodev,noauto,nosuid,user,errors=continue", 0, NULL, 0 },
-    { "ext2", "nodev,noauto,nosuid,user,errors=continue", 0, NULL, 0 },
+    { "ext3", "nodev,noauto,nosuid,user,errors=remount-ro", 0, NULL, 0 },
+    { "ext2", "nodev,noauto,nosuid,user,errors=remount-ro", 0, NULL, 0 },
     { "reiserfs", "nodev,noauto,nosuid,user", 0, NULL, 0 },
     { "reiser4", "nodev,noauto,nosuid,user", 0, NULL, 0 },
     { "xfs", "nodev,noauto,nosuid,user", 0, NULL, 0 },
-    { "jfs", "nodev,noauto,nosuid,user,errors=continue", 0, NULL, 
+    { "jfs", "nodev,noauto,nosuid,user,errors=remount-ro", 0, NULL, 
       ",iocharset=%s"},
     { "omfs", "nodev,noauto,nosuid,user", 0, NULL, 0 },
     { "ntfs-fuse", "nosuid,nodev,user", 1, "077", 
